package com.unis.module.coding.controller.admin.delivery;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.pojo.CommonResult;
import com.unis.framework.common.util.object.BeanUtils;
import com.unis.framework.security.core.LoginUser;
import com.unis.framework.security.core.util.SecurityFrameworkUtils;
import com.unis.module.coding.controller.admin.caxx.vo.CaxxSaveReqVO;
import com.unis.module.coding.controller.admin.delivery.vo.*;
import com.unis.module.coding.controller.admin.dwxx.vo.DwxxSaveReqVO;
import com.unis.module.coding.controller.admin.kqxx.vo.KqxxSaveReqVO;
import com.unis.module.coding.dal.dataobject.caxx.CaxxDO;
import com.unis.module.coding.dal.dataobject.codingcaxx.CodingCaxxDO;
import com.unis.module.coding.dal.dataobject.codingdwxx.CodingDwxxDO;
import com.unis.module.coding.dal.dataobject.codingkqxx.CodingKqxxDO;
import com.unis.module.coding.dal.dataobject.dwxx.DwxxDO;
import com.unis.module.coding.dal.dataobject.kqxx.KqxxDO;
import com.unis.module.coding.dal.mysql.caxx.CaxxMapper;
import com.unis.module.coding.dal.mysql.codingcaxx.CodingCaxxMapper;
import com.unis.module.coding.dal.mysql.codingdwxx.CodingDwxxMapper;
import com.unis.module.coding.dal.mysql.codingkqxx.CodingKqxxMapper;
import com.unis.module.coding.dal.mysql.dwxx.DwxxMapper;
import com.unis.module.coding.dal.mysql.kqxx.KqxxMapper;
import com.unis.module.coding.service.caxx.CaxxService;
import com.unis.module.coding.service.delivery.DeliveryService;
import com.unis.module.coding.service.dwxx.DwxxService;
import com.unis.module.coding.service.kqxx.KqxxService;
import com.unis.module.system.dal.dataobject.arealevel.AreaLevelDO;
import com.unis.module.system.dal.mysql.arealevel.AreaLevelMapper;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.framework.common.pojo.CommonResult.success;
import static com.unis.module.infra.enums.ErrorCodeConstants.ERROR;

/**
 * @author qingsong.han
 * @description:
 * @create 2025-01-16 15:22
 */
@Tag(name = "交割仓选择")
@RestController
@RequestMapping("/coding/delivery")
@Validated
@Slf4j
public class DeliveryController {
    @Resource
    private DwxxService dwxxService;
    @Resource
    private DeliveryService deliveryService;
    @Resource
    private KqxxService kqxxService;
    @GetMapping("/page")
    @Operation(summary = "获得交收仓选择分页")
    @PreAuthorize("@ss.hasPermission('coding:delivery:query')")
    public CommonResult<PageResult<DeliveryRespVO>> getDeliveryPage(@Valid DeliveryPageReqVO pageReqVO) {
        return success(dwxxService.getDeliveryPage(pageReqVO));
    }
    @GetMapping("/province-selected/page")
    @Operation(summary = "国家查看省已选交收仓选择分页")
    @PreAuthorize("@ss.hasPermission('coding:delivery:query')")
    public CommonResult<PageResult<SpareRespVO>> getProvinceSelectedPage(@Valid SparePageReqVO pageReqVO) {
        return success(dwxxService.getProvinceSelectedPage(pageReqVO));
    }

    @GetMapping("/storePage")
    @Operation(summary = "获得仓房列表分页")
    @PreAuthorize("@ss.hasPermission('coding:cfxx:query')")
    public CommonResult<List<StoreRespVO>> getStorePage(@Valid StorePageReqVO pageReqVO) {
        return success(dwxxService.getStorePage(pageReqVO));
    }

    @PostMapping("/updateCaxxByIds")
    @Operation(summary = "仓房列表已选更新")
    @PreAuthorize("@ss.hasPermission('coding:cfxx:select')")
    public CommonResult<Boolean> updateCaxxByIds(@Valid @RequestBody CaxxUpdateReqVO updateReqVO) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        log.info("loginUser: {}", loginUser);
        if (ObjectUtils.isNotEmpty(loginUser)) {
            /*system_users: area_code,area_level,sheng_code,shi_code,xian_code
             *  超级管理员: null
             *  国家交易中心: area_code='000000' area_level=0 其它未null
             *  其它情况: 不未 null
             */
            String areaLevel = loginUser.getInfo().get("areaLevel");
            if (StringUtils.isNotBlank(areaLevel)) {
                updateReqVO.setAreaLevel(areaLevel);
                dwxxService.updateSelectedCaxx(updateReqVO);
            } else { // admin 管理员
                // 无修改数据权限
                log.info("超级管理员无修改数据权限loginUser: {}", loginUser);
            }
        }
        return success(true);
    }

    @PostMapping("/revertCaxx")
    @Operation(summary = "仓房退回")
    @PreAuthorize("@ss.hasPermission('coding:cfxx:return')")
    public CommonResult<Boolean> revertCaxx(@Valid @RequestBody CaxxUpdateReqVO updateReqVO) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        log.info("loginUser: {}", loginUser);
        if (ObjectUtils.isNotEmpty(loginUser)) {
            String areaLevel = loginUser.getInfo().get("areaLevel");
            if (StringUtils.isNotBlank(areaLevel)) {
                updateReqVO.setAreaLevel(areaLevel);
                dwxxService.revertCaxx(updateReqVO);
            } else { // admin 管理员
                log.info("超级管理员无修改数据权限loginUser: {}", loginUser);
            }
        }
        return success(true);
    }
    @GetMapping("/revertKqxx")
    @Operation(summary = "库区退回")
    @PreAuthorize("@ss.hasPermission('coding:cfxx:return')")
    public CommonResult<Boolean> revertKqxx(@Valid @RequestParam("kqIds") List<Long> ids) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        log.info("loginUser: {}", loginUser);
        if (ObjectUtils.isNotEmpty(loginUser)) {
            String areaLevel = loginUser.getInfo().get("areaLevel");
            if (StringUtils.isNotBlank(areaLevel)) {
                dwxxService.revertKqxx(ids,areaLevel);
            } else { // admin 管理员
                log.info("超级管理员无修改数据权限loginUser: {}", loginUser);
            }
        }
        return success(true);
    }
    @PostMapping("/createByAll")
    @Operation(summary = "创建单位/库区/仓房/财务/交通运输")
    @PreAuthorize("@ss.hasPermission('coding:delivery:createByAll')")
    public CommonResult<Object> createByAll(@Valid @RequestBody DeliverySaveVO createReqVO) {
        return success(deliveryService.createByAll(createReqVO));
    }

}
