package com.unis.module.coding.controller.admin.delivery;

import com.unis.framework.common.pojo.CommonResult;
import com.unis.framework.common.pojo.PageResult;
import com.unis.module.coding.controller.admin.delivery.vo.SparePageReqVO;
import com.unis.module.coding.controller.admin.delivery.vo.SpareRespVO;
import com.unis.module.coding.service.caxx.CaxxService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import static com.unis.framework.common.pojo.CommonResult.success;

/**
 * @author qingsong.han
 * @description:
 * @create 2025-02-07 8:56
 */
@Tag(name = "交收仓列表")
@RestController
@RequestMapping("/coding/deliverySpare")
@Validated
@Slf4j
public class DeliverySpareController {
    @Resource
    private CaxxService caxxService;

    @PostMapping("/page")
    @Operation(summary = "交收仓列表分页")
    @PreAuthorize("@ss.hasPermission('coding:deliverySpare:query')")
    public CommonResult<PageResult<SpareRespVO>> getDeliverySparePage(@Valid @RequestBody SparePageReqVO pageReqVO) {
        return success(caxxService.getDeliverySparePage(pageReqVO));
    }
    @PostMapping("/identify/page")
    @Operation(summary = "认定交收仓分页")
    @PreAuthorize("@ss.hasPermission('DetermineDeliveryWarehouse:query')")
    public CommonResult<PageResult<SpareRespVO>> getIdentifySparePage(@Valid @RequestBody SparePageReqVO pageReqVO) {
        return success(caxxService.getIdentifySparePage(pageReqVO));
    }
    @PostMapping("/select/page")
    @Operation(summary = "选定交收仓分页")
    @PreAuthorize("@ss.hasPermission('SelectDeliveryWarehouseList:query')")
    public CommonResult<PageResult<SpareRespVO>> getSelectSparePage(@Valid @RequestBody SparePageReqVO pageReqVO) {
        return success(caxxService.getSelectSparePage(pageReqVO));
    }
}
