package com.unis.module.coding.service.caxx;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yitter.idgen.YitIdHelper;
import com.unis.framework.security.core.LoginUser;
import com.unis.framework.security.core.util.AreaUtils;
import com.unis.framework.security.core.util.SecurityFrameworkUtils;
import com.unis.module.coding.controller.admin.delivery.vo.DeliveryRespVO;
import com.unis.module.coding.controller.admin.delivery.vo.SparePageReqVO;
import com.unis.module.coding.controller.admin.delivery.vo.SpareRespVO;
import com.unis.module.system.dal.dataobject.permission.UserRoleDO;
import com.unis.module.system.dal.dataobject.user.AdminUserDO;
import com.unis.module.system.dal.mysql.permission.UserRoleMapper;
import com.unis.module.system.dal.mysql.user.AdminUserMapper;
import com.unis.module.system.enums.permission.RoleIdEnum;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import com.unis.module.coding.controller.admin.caxx.vo.*;
import com.unis.module.coding.dal.dataobject.caxx.CaxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.caxx.CaxxMapper;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.CAXX_NOT_EXISTS;
import static com.unis.module.infra.enums.ErrorCodeConstants.ERROR;

/**
 * 仓廒信息; Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class CaxxServiceImpl implements CaxxService {

    @Resource
    private CaxxMapper caxxMapper;
    @Resource
    private  UserRoleMapper userRoleMapper;
    @Resource
    private AdminUserMapper adminUserMapper;

    @Override
    public Long createCaxx(CaxxSaveReqVO createReqVO) {
        // 插入
        CaxxDO caxx = BeanUtils.toBean(createReqVO, CaxxDO.class);
        caxx.setId(YitIdHelper.nextId());
        caxx.setSjly(0);
        caxxMapper.insert(caxx);
        // 返回
        return caxx.getId();
    }

    @Override
    public void updateCaxx(CaxxSaveReqVO updateReqVO) {
        // 校验存在
        validateCaxxExists(updateReqVO.getId());
        // 更新
        CaxxDO updateObj = BeanUtils.toBean(updateReqVO, CaxxDO.class);
        caxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteCaxx(Long id) {
        // 校验存在
        validateCaxxExists(id);
        // 删除
        caxxMapper.deleteById(id);
    }

    private void validateCaxxExists(Long id) {
        if (caxxMapper.selectById(id) == null) {
            throw exception(CAXX_NOT_EXISTS);
        }
    }

    @Override
    public CaxxDO getCaxx(Long id) {
        return caxxMapper.selectById(id);
    }

    @Override
    public PageResult<CaxxDO> getCaxxPage(CaxxPageReqVO pageReqVO) {
        return caxxMapper.selectPage(pageReqVO);
    }

    @Override
    public PageResult<SpareRespVO> getDeliverySparePage(SparePageReqVO pageReqVO) {
        Long loginUserId = SecurityFrameworkUtils.getLoginUserId();
        AdminUserDO adminUserDO = adminUserMapper.selectById(loginUserId);
        if (ObjectUtils.isEmpty(adminUserDO)) {
            throw exception(ERROR,"不存在用户信心信息");
        }
        Integer areaLevel = adminUserDO.getAreaLevel();
        if (StringUtils.isNotBlank(pageReqVO.getDwmc())) {
            pageReqVO.setDwmc(String.format("%s%s%s", "%", pageReqVO.getDwmc(), "%"));
        }
        if (StringUtils.isNotBlank(pageReqVO.getKqmc())) {
            pageReqVO.setKqmc(String.format("%s%s%s", "%", pageReqVO.getKqmc(), "%"));
        }
        Page<SpareRespVO> page =new  Page<SpareRespVO>();
        // 国家交易中心已选
        if (0==areaLevel|| ObjectUtil.isEmpty(areaLevel)) {
            page = caxxMapper.getDeliverySparePage(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
        }
        //省级交易中心与银行用户
        if (1==areaLevel) {
            String areaCode = adminUserDO.getAreaCode();
            pageReqVO.setShengCode(areaCode);
            //获取当前用户角色
            List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
            if (ObjectUtils.isEmpty(userRoleList)) {
                throw exception(ERROR,"不存在角色信息");
            }
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                page = caxxMapper.selectWrapperPageForBank(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }else{
                page = caxxMapper.selectWrapperPageForSheng(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
                List<SpareRespVO> records = page.getRecords();
                if (!ObjectUtils.isEmpty(records)){
                    records.stream().forEach(s->{
                        String fileIds = s.getFileIds();
                        if (fileIds!=null&&!"".equals(fileIds)){
                            String[] fileIdArray = fileIds.split(",");
                            int length = fileIdArray.length;
                            s.setFileNumber(length);
                        }else {
                            s.setFileNumber(0);
                        }
                    });
                }
            }
        }
        return new PageResult<>(page.getRecords(), page.getTotal());
    }

    @Override
    public PageResult<SpareRespVO> getIdentifySparePage(SparePageReqVO pageReqVO) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (ObjectUtils.isEmpty(loginUser)) {
            throw exception(ERROR,"不存在用户信息");
        }
        String areaLevel = loginUser.getInfo().get("areaLevel");
        if (StringUtils.isNotBlank(pageReqVO.getDwmc())) {
            pageReqVO.setDwmc(String.format("%s%s%s", "%", pageReqVO.getDwmc(), "%"));
        }
        if (StringUtils.isNotBlank(pageReqVO.getKqmc())) {
            pageReqVO.setKqmc(String.format("%s%s%s", "%", pageReqVO.getKqmc(), "%"));
        }
        Page<SpareRespVO> page =new  Page<SpareRespVO>();
        // 国家交易中心已选
        if ("0".equals(areaLevel)|| ObjectUtil.isEmpty(areaLevel)) {
            page = caxxMapper.getIdentifySparePage(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
        }
        //省级交易中心与银行用户
        if ("1".equals(areaLevel)) {
            String shengCode = loginUser.getInfo().get("shengCode");
            pageReqVO.setShengCode(shengCode);
            String roleIds = loginUser.getInfo().get("roleIds");
            if (ObjectUtils.isEmpty(roleIds)) {
                throw exception(ERROR,"当前用户不存在角色信息");
            }
            String[] items = roleIds.split(",");
            List<String> roleIdList = Arrays.asList(items);
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                String bankType = loginUser.getInfo().get("bankType");
                if (StringUtils.isBlank(bankType)) {
                    throw exception(ERROR, "当前银行用户不存在银行信息");
                }
                pageReqVO.setYhmc(bankType);
                page = caxxMapper.getIdentifyPageForBank(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }else{
                page = caxxMapper.getIdentifyPageForSheng(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }
        }
        return new PageResult<>(page.getRecords(), page.getTotal());
    }

    @Override
    public PageResult<SpareRespVO> getSelectSparePage(SparePageReqVO pageReqVO) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (ObjectUtils.isEmpty(loginUser)) {
            throw exception(ERROR,"不存在用户信息");
        }
        String areaLevel = loginUser.getInfo().get("areaLevel");
        if (StringUtils.isNotBlank(pageReqVO.getDwmc())) {
            pageReqVO.setDwmc(String.format("%s%s%s", "%", pageReqVO.getDwmc(), "%"));
        }
        if (StringUtils.isNotBlank(pageReqVO.getKqmc())) {
            pageReqVO.setKqmc(String.format("%s%s%s", "%", pageReqVO.getKqmc(), "%"));
        }
        Page<SpareRespVO> page =new  Page<SpareRespVO>();
        // 国家交易中心已选
        if ("0".equals(areaLevel)|| ObjectUtil.isEmpty(areaLevel)) {
            page = caxxMapper.getSelectSparePage(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
        }
        //省级交易中心与银行用户
        if ("1".equals(areaLevel)) {
            String shengCode = loginUser.getInfo().get("shengCode");
            pageReqVO.setShengCode(shengCode);
            String roleIds = loginUser.getInfo().get("roleIds");
            if (ObjectUtils.isEmpty(roleIds)) {
                throw exception(ERROR,"当前用户不存在角色信息");
            }
            String[] items = roleIds.split(",");
            List<String> roleIdList = Arrays.asList(items);
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                String bankType = loginUser.getInfo().get("bankType");
                if (StringUtils.isBlank(bankType)){
                    throw exception(ERROR,"当前银行用户不存在银行信息");
                }
                pageReqVO.setYhmc(bankType);
                page = caxxMapper.getSelectPageForBank(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }else{
                page = caxxMapper.getSelectPageForSheng(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }
        }
        return new PageResult<>(page.getRecords(), page.getTotal());
    }

}