package com.unis.module.coding.service.crkxx;

import com.github.yitter.idgen.YitIdHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;

import com.unis.module.coding.controller.admin.crkxx.vo.*;
import com.unis.module.coding.dal.dataobject.crkxx.CrkxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.crkxx.CrkxxMapper;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.CRKXX_NOT_EXISTS;

/**
 * 出入库信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class CrkxxServiceImpl implements CrkxxService {

    @Resource
    private CrkxxMapper crkxxMapper;

    @Override
    public Long createCrkxx(CrkxxSaveReqVO createReqVO) {
        // 插入
        CrkxxDO crkxx = BeanUtils.toBean(createReqVO, CrkxxDO.class);
        //创建id
        crkxx.setId(YitIdHelper.nextId());
        crkxx.setDeleted(false);
        crkxxMapper.insert(crkxx);
        // 返回
        return crkxx.getId();
    }

    @Override
    public void updateCrkxx(CrkxxSaveReqVO updateReqVO) {
        // 校验存在
        validateCrkxxExists(updateReqVO.getId());
        // 更新
        CrkxxDO updateObj = BeanUtils.toBean(updateReqVO, CrkxxDO.class);
        crkxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteCrkxx(Long id) {
        // 校验存在
        validateCrkxxExists(id);
        CrkxxDO crkxxDO=new CrkxxDO();
        crkxxDO.setId(id);
        crkxxDO.setDeleted(false);
        // 删除
        crkxxMapper.updateById(crkxxDO);
    }

    private void validateCrkxxExists(Long id) {
        if (crkxxMapper.selectById(id) == null) {
            throw exception(CRKXX_NOT_EXISTS);
        }
    }

    @Override
    public CrkxxDO getCrkxx(Long id) {
        return crkxxMapper.selectById(id);
    }

    @Override
    public PageResult<CrkxxDO> getCrkxxPage(CrkxxPageReqVO pageReqVO) {
        return crkxxMapper.selectPage(pageReqVO);
    }

}