package com.unis.module.coding.service.cwxx;

import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.github.yitter.idgen.YitIdHelper;
import com.unis.module.coding.controller.admin.cwxxyear.vo.CwxxYearSaveReqVO;
import com.unis.module.coding.dal.dataobject.cwxxyear.CwxxYearDO;
import com.unis.module.coding.dal.mysql.cwxxyear.CwxxYearMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import com.unis.module.coding.controller.admin.cwxx.vo.*;
import com.unis.module.coding.dal.dataobject.cwxx.CwxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.cwxx.CwxxMapper;

import java.util.List;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.CWXX_NOT_EXISTS;
import static com.unis.module.infra.enums.ErrorCodeConstants.ERROR;

/**
 * 财务信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class CwxxServiceImpl implements CwxxService {

    @Resource
    private CwxxMapper cwxxMapper;
    @Resource
    private CwxxYearMapper cwxxYearMapper;

    @Override
    public Long createCwxx(CwxxSaveReqVO createReqVO) {
        // 插入
        CwxxDO cwxx = BeanUtils.toBean(createReqVO, CwxxDO.class);
        cwxx.setId(YitIdHelper.nextId());
        cwxxMapper.insert(cwxx);
        // 返回
        return cwxx.getId();
    }

    @Override
    public void updateCwxx(CwxxSaveReqVO updateReqVO) {
        // 校验存在
        validateCwxxExists(updateReqVO.getId());
        // 更新
        CwxxDO updateObj = BeanUtils.toBean(updateReqVO, CwxxDO.class);
        cwxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteCwxx(Long id) {
        // 校验存在
        validateCwxxExists(id);
        // 删除
        cwxxMapper.deleteById(id);
    }

    private void validateCwxxExists(Long id) {
        if (cwxxMapper.selectById(id) == null) {
            throw exception(CWXX_NOT_EXISTS);
        }
    }

    @Override
    public CwxxRespVO getCwxx(Long id) {
        CwxxDO cwxxDO = cwxxMapper.selectById(id);
        if (ObjectUtils.isEmpty(cwxxDO)){
            throw exception(ERROR,"不存在财务信息");
        }
        CwxxRespVO cwxxRespVO = BeanUtils.toBean(cwxxDO, CwxxRespVO.class);
        List<CwxxYearDO> cwxxYearDOS = cwxxYearMapper.selectByCwxxId(id);
        if (!ObjectUtils.isEmpty(cwxxYearDOS)){
            List<CwxxYearSaveReqVO> cwxxYearSaveReqVOS = BeanUtils.toBean(cwxxYearDOS, CwxxYearSaveReqVO.class);
            cwxxRespVO.setCwxxYearList(cwxxYearSaveReqVOS);
        }
        return cwxxRespVO;
    }

    @Override
    public PageResult<CwxxDO> getCwxxPage(CwxxPageReqVO pageReqVO) {
        return cwxxMapper.selectPage(pageReqVO);
    }

}