package com.unis.module.coding.service.delivery;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.unis.module.coding.controller.admin.caxx.vo.CaxxSaveReqVO;
import com.unis.module.coding.controller.admin.cwxx.vo.CwxxSaveReqVO;
import com.unis.module.coding.controller.admin.delivery.vo.CaxxUpdateReqVO;
import com.unis.module.coding.controller.admin.delivery.vo.DeliverySaveVO;
import com.unis.module.coding.controller.admin.dwxx.vo.DwxxSaveReqVO;
import com.unis.module.coding.dal.mysql.kqxx.KqxxMapper;
import com.unis.module.coding.service.caxx.CaxxService;
import com.unis.module.coding.service.cwxx.CwxxService;
import com.unis.module.coding.service.cwxxyear.CwxxYearService;
import com.unis.module.coding.service.dwxx.DwxxService;
import com.unis.module.coding.service.kqxx.KqxxService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description:
 * @create 2025-01-22 15:28
 */
@Service
public class DeliveryServiceImpl implements DeliveryService {
    @Resource
    private DwxxService dwxxService;
    @Resource
    private KqxxService kqxxService;
    @Resource
    private KqxxMapper kqxxMapper;
    @Resource
    private CaxxService caxxService;
    @Resource
    private CwxxService cwxxService;
    @Resource
    private CwxxYearService cwxxYearService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateCaxxByIds(CaxxUpdateReqVO updateReqVO) {
        List<Long> ids = updateReqVO.getIds();
        if (CollectionUtils.isNotEmpty(ids)) {
            ids.forEach(id -> {
                CaxxSaveReqVO updateVO = new CaxxSaveReqVO();
                updateVO.setId(id);
                updateVO.setYxcf(updateReqVO.getYxcf());
                caxxService.updateCaxx(updateVO);
            });
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Object createByAll(DeliverySaveVO createReqVO) {
        // 单位信息
        if (ObjectUtils.isNotEmpty(createReqVO.getDwxxReqVO())) {
            Long dwxx = dwxxService.createDwxx(createReqVO.getDwxxReqVO());

            // 库区信息
            if (ObjectUtils.isNotEmpty(createReqVO.getKqxxReqVO())) {
                // set 单位id
                createReqVO.getKqxxReqVO().setDwid(dwxx);
                /*
                 * 生成库区编码
                 */
                // 单位信息社会统一信用编码
                String tyxydm = createReqVO.getDwxxReqVO().getTyxydm();
                // 库区编码
                String kqdm = kqxxMapper.getBySHXYDM(tyxydm);
                // 初始化后位
                Integer after = 1;
                if (StringUtils.isNotBlank(kqdm)) {
                    // 截取18位之后的参数
                    String substring = kqdm.substring(18);
                    if (StringUtils.isNotBlank(substring)) {
                        after += Integer.parseInt(substring);
                    }
                }
                kqdm = String.format("%s%s", kqdm, after);
                createReqVO.getKqxxReqVO().setKqdm(kqdm);
                Long kqxx = kqxxService.createKqxx(createReqVO.getKqxxReqVO());

                // 仓房信息
                if (CollectionUtils.isNotEmpty(createReqVO.getCaxxReqVOList())) {
                    createReqVO.getCaxxReqVOList().forEach(caxx -> {
                        caxx.setKqid(kqxx);
                        caxxService.createCaxx(caxx);
                    });
                }

                // 财务信息
                CwxxSaveReqVO cwxxReqVO = createReqVO.getCwxxReqVO();
                if (ObjectUtils.isNotEmpty(cwxxReqVO)) {
                    cwxxReqVO.setKqid(kqxx);
                    cwxxReqVO.setDeptId(dwxx);
                    Long cwxx = cwxxService.createCwxx(cwxxReqVO);
                    // 财年信息
                    if (CollectionUtils.isNotEmpty(cwxxReqVO.getCwxxYearList())) {
                        cwxxReqVO.getCwxxYearList().forEach(cwxxYear -> {
                            cwxxYear.setCwxxId(cwxx);
                            cwxxYearService.createCwxxYear(cwxxYear);
                        });
                    }
                }
            }
        }
        // 交通运输情况
        return null;
    }
}
