package com.unis.module.coding.service.dwxx;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yitter.idgen.YitIdHelper;
import com.unis.framework.common.util.business.PermissionUtils;
import com.unis.framework.security.core.LoginUser;
import com.unis.framework.security.core.util.AreaUtils;
import com.unis.framework.security.core.util.SecurityFrameworkUtils;
import com.unis.module.coding.controller.admin.delivery.vo.*;
import com.unis.module.coding.dal.dataobject.bank.BankDO;
import com.unis.module.coding.dal.dataobject.caxx.CaxxDO;
import com.unis.module.coding.dal.dataobject.codingcaxx.CodingCaxxDO;
import com.unis.module.coding.dal.dataobject.codingdwxx.CodingDwxxDO;
import com.unis.module.coding.dal.dataobject.codingkqxx.CodingKqxxDO;
import com.unis.module.coding.dal.dataobject.cwxx.CwxxDO;
import com.unis.module.coding.dal.dataobject.kqxx.KqxxDO;
import com.unis.module.coding.dal.dataobject.province.ProvinceDO;
import com.unis.module.coding.dal.mysql.bank.BankMapper;
import com.unis.module.coding.dal.mysql.caxx.CaxxMapper;
import com.unis.module.coding.dal.mysql.codingcaxx.CodingCaxxMapper;
import com.unis.module.coding.dal.mysql.codingdwxx.CodingDwxxMapper;
import com.unis.module.coding.dal.mysql.codingkqxx.CodingKqxxMapper;
import com.unis.module.coding.dal.mysql.cwxx.CwxxMapper;
import com.unis.module.coding.dal.mysql.cwxxyear.CwxxYearMapper;
import com.unis.module.coding.dal.mysql.kqxx.KqxxMapper;
import com.unis.module.coding.dal.mysql.province.ProvinceMapper;
import com.unis.module.core.enums.XZQHLEVEL;
import com.unis.module.core.enums.YXZT;
import com.unis.module.system.dal.dataobject.arealevel.AreaLevelDO;
import com.unis.module.system.dal.dataobject.permission.UserRoleDO;
import com.unis.module.system.dal.dataobject.user.AdminUserDO;
import com.unis.module.system.dal.mysql.arealevel.AreaLevelMapper;
import com.unis.module.system.dal.mysql.permission.UserRoleMapper;
import com.unis.module.system.dal.mysql.user.AdminUserMapper;
import com.unis.module.system.enums.permission.RoleIdEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import com.unis.module.coding.controller.admin.dwxx.vo.*;
import com.unis.module.coding.dal.dataobject.dwxx.DwxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.dwxx.DwxxMapper;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.DWXX_LOGIN_USER_EXISTS;
import static com.unis.module.core.enums.ErrorCodeConstants.DWXX_NOT_EXISTS;
import static com.unis.module.infra.enums.ErrorCodeConstants.ERROR;

/**
 * 单位信息 Service 实现类
 *
 * @author 超级管理员
 */
@Slf4j
@Service
@Validated
public class DwxxServiceImpl implements DwxxService {

    @Resource
    private DwxxMapper dwxxMapper;
    @Resource
    private UserRoleMapper userRoleMapper;
    @Resource
    private AdminUserMapper adminUserMapper;
    @Resource
    private CodingKqxxMapper codingKqxxMapper;
    @Resource
    private CodingCaxxMapper codingCaxxMapper;
    @Resource
    private CodingDwxxMapper codingDwxxMapper;
    @Resource
    private KqxxMapper kqxxMapper;
    @Resource
    private CaxxMapper caxxMapper;
    @Resource
    private AreaLevelMapper areaLevelMapper;
    @Resource
    private ProvinceMapper provinceMapper;
    @Resource
    private BankMapper bankMapper;
    @Resource
    private CwxxMapper  cwxxMapper;
    @Resource
    private CwxxYearMapper cwxxYearMapper;
    @Override
    public Long createDwxx(DwxxSaveReqVO createReqVO) {
        // 插入
        DwxxDO dwxx = BeanUtils.toBean(createReqVO, DwxxDO.class);
        dwxx.setId(YitIdHelper.nextId());
        /**
         * {
         * 	"id": 633249312886853,
         * 	"info": {
         * 		"nickname": "北京局管理员用户",
         * 		"deptId": "1171201049703"
         *        },
         * 	"userType": 2
         * }
         */
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (ObjectUtils.isNotEmpty(loginUser)) {
            String deptId = loginUser.getInfo().get("deptId");
            dwxx.setDwDeptId(deptId);
        } else {
            throw exception(DWXX_LOGIN_USER_EXISTS);
        }
        dwxxMapper.insert(dwxx);
        // 返回
        return dwxx.getId();
    }

    @Override
    public void updateDwxx(DwxxSaveReqVO updateReqVO) {
        // 校验存在
        validateDwxxExists(updateReqVO.getId());
        // 更新
        DwxxDO updateObj = BeanUtils.toBean(updateReqVO, DwxxDO.class);
        dwxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteDwxx(Long id) {
        // 校验存在
        validateDwxxExists(id);
        // 删除
        dwxxMapper.deleteById(id);
    }

    private void validateDwxxExists(Long id) {
        if (dwxxMapper.selectById(id) == null) {
            throw exception(DWXX_NOT_EXISTS);
        }
    }

    @Override
    public DwxxDO getDwxx(Long id) {
        return dwxxMapper.selectById(id);
    }

    @Override
    public PageResult<DwxxDO> getDwxxPage(DwxxPageReqVO pageReqVO) {
        return dwxxMapper.selectPage(pageReqVO);
    }

    @Override
    public PageResult<DeliveryRespVO> getDeliveryPage(DeliveryPageReqVO pageReqVO) {
        if (StringUtils.isNotBlank(pageReqVO.getDwmc())) {
            pageReqVO.setDwmc(String.format("%s%s%s", "%", pageReqVO.getDwmc(), "%"));
        }
        Long loginUserId = SecurityFrameworkUtils.getLoginUserId();
        AdminUserDO adminUserDO = adminUserMapper.selectById(loginUserId);
        if (ObjectUtils.isEmpty(adminUserDO)) {
            throw exception(ERROR, "不存在用户信心信息");
        }
        Integer areaLevel = adminUserDO.getAreaLevel();
        Page<DeliveryRespVO> page = new Page<DeliveryRespVO>();
        // 国家交易中心已选
        if (0 == areaLevel || ObjectUtil.isEmpty(areaLevel)) {
            if (pageReqVO.getAreaCode() != null) {
                // 数据权限
                pageReqVO.setAreaCode(AreaUtils.getAreaCode(pageReqVO.getAreaLevel(), pageReqVO.getAreaCode(), pageReqVO.getParentCode()));
            }
            page = dwxxMapper.selectWrapperPage(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);

        }
        //省级交易中心与银行用户
        if (1 == areaLevel) {
            String areaCode = adminUserDO.getAreaCode();
            pageReqVO.setAreaSheng(areaCode);
            if (!ObjectUtils.isEmpty(pageReqVO.getAreaLevel()) && pageReqVO.getAreaCode() != null) {
                if (XZQHLEVEL.SHI.getCode().equals(pageReqVO.getAreaLevel())) {
                    pageReqVO.setAreaShi(pageReqVO.getAreaCode());
                }
                if (XZQHLEVEL.XIAN.getCode().equals(pageReqVO.getAreaLevel())) {
                    pageReqVO.setAreaXian(pageReqVO.getAreaCode());
                }
            }
            //获取当前用户角色
            List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
            if (ObjectUtils.isEmpty(userRoleList)) {
                throw exception(ERROR, "不存在角色信息");
            }
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                page = dwxxMapper.selectWrapperPageForBank(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            } else {
                page = dwxxMapper.selectWrapperPageForSheng(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
            }

        }
        return new PageResult<>(page.getRecords(), page.getTotal());
    }

    @Override
    public List<StoreRespVO> getStorePage(StorePageReqVO pageReqVO) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (ObjectUtils.isEmpty(loginUser)) {
            throw exception(ERROR, "不存在用户信息");
        }
        String areaLevel = loginUser.getInfo().get("areaLevel");
        Long loginUserId = loginUser.getId();
        //获取当前用户角色
        List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
        if (ObjectUtils.isEmpty(userRoleList)) {
            throw exception(ERROR, "不存在角色信息");
        }
        // 国家交易中心已选
        if ("0".equals(areaLevel) || ObjectUtil.isEmpty(areaLevel)) {
            if (YXZT.NOT_SELECTED.getCode().equals(pageReqVO.getYxcf())) {
                List<StoreRespVO> storeListForNation = dwxxMapper.getStoreListForNation(pageReqVO);
                List<CaxxDO> caxxDOS = caxxMapper.selectListByKqId(pageReqVO.getKqId());
                if (!ObjectUtils.isEmpty(storeListForNation)) {
                    if (!ObjectUtils.isEmpty(caxxDOS)) {
                        List<Long> idsExist = caxxDOS.stream().map(CaxxDO::getId).collect(Collectors.toList());
                        if (!ObjectUtils.isEmpty(idsExist)) {
                            storeListForNation.removeIf(caxxDO -> idsExist.contains(caxxDO.getId()));
                        }
                    }
                    return storeListForNation;
                }
            } else if (YXZT.SELECTED.getCode().equals(pageReqVO.getYxcf()) || YXZT.OPTION.getCode().equals(pageReqVO.getYxcf())) {
                List<CaxxDO> caxxDOS = caxxMapper.selectListByKqId(pageReqVO.getKqId());
                if (!ObjectUtils.isEmpty(caxxDOS)) {
                    List<StoreRespVO> selectedStoreSForNation = BeanUtils.toBean(caxxDOS, StoreRespVO.class);
                    return selectedStoreSForNation;
                }
            }else if (YXZT.IDENTIFY.getCode().equals(pageReqVO.getYxcf())){
                 List<StoreRespVO> storeRespVOS = caxxMapper.selectListForIdentify(pageReqVO.getKqId(), null);
                 return storeRespVOS;
            }else if (YXZT.SELECT.getCode().equals(pageReqVO.getYxcf())){

            }
        }
        if ("1".equals(areaLevel)) {
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {// 银行已选
                String bankType = loginUser.getInfo().get("bankType");
                if (StringUtils.isBlank(bankType)){
                    throw exception(ERROR,"当前银行用户不存在银行信息");
                }
                if (YXZT.NOT_SELECTED.getCode().equals(pageReqVO.getYxcf())) {
                    List<StoreRespVO> storeListForBank = provinceMapper.getStoreListForProvince(pageReqVO.getKqId(), 1);
                    List<StoreRespVO> storeListSelelct = bankMapper.getStoreListForBank(pageReqVO.getKqId());
                    if (!ObjectUtils.isEmpty(storeListForBank)) {
                        if (!ObjectUtils.isEmpty(storeListSelelct)) {
                            List<Long> idsExist = storeListSelelct.stream().map(StoreRespVO::getId).collect(Collectors.toList());
                            if (!ObjectUtils.isEmpty(idsExist)) {
                                storeListForBank.removeIf(a -> idsExist.contains(a.getId()));
                            }
                        }
                        return storeListForBank;
                    }
                } else if (YXZT.SELECTED.getCode().equals(pageReqVO.getYxcf()) || YXZT.OPTION.getCode().equals(pageReqVO.getYxcf())) {
                    List<StoreRespVO> storeListForBank = bankMapper.getStoreListForBank(pageReqVO.getKqId());
                    return storeListForBank;
                }else if (YXZT.IDENTIFY.getCode().equals(pageReqVO.getYxcf())){
                    List<StoreRespVO> storeRespVOS = caxxMapper.selectListForIdentify(pageReqVO.getKqId(), bankType);
                    return storeRespVOS;
                }else if (YXZT.SELECT.getCode().equals(pageReqVO.getYxcf())){

                }
            } else {// 省已选
                if (YXZT.NOT_SELECTED.getCode().equals(pageReqVO.getYxcf())) {
                    List<CaxxDO> caxxDOS = caxxMapper.selectListByKqId(pageReqVO.getKqId());
                    List<StoreRespVO> storeListSelect = provinceMapper.getStoreListForProvince(pageReqVO.getKqId(), 0);
                    List<StoreRespVO> storeListForProvice = new ArrayList<>();
                    if (!ObjectUtils.isEmpty(caxxDOS)) {
                        if (!ObjectUtils.isEmpty(storeListSelect)) {
                            List<Long> idsExist = storeListSelect.stream().map(StoreRespVO::getId).collect(Collectors.toList());
                            if (!ObjectUtils.isEmpty(idsExist)) {
                                caxxDOS.removeIf(a -> idsExist.contains(a.getId()));
                            }
                        }
                        if (!ObjectUtils.isEmpty(caxxDOS)) {
                            storeListForProvice = BeanUtils.toBean(caxxDOS, StoreRespVO.class);
                        }
                        return storeListForProvice;
                    }

                } else if (YXZT.SELECTED.getCode().equals(pageReqVO.getYxcf()) || YXZT.OPTION.getCode().equals(pageReqVO.getYxcf())) {
                    List<StoreRespVO> storeListForProvince = provinceMapper.getStoreListForProvince(pageReqVO.getKqId(), 0);
                    return storeListForProvince;
                }else if (YXZT.IDENTIFY.getCode().equals(pageReqVO.getYxcf())){
                    List<StoreRespVO> storeRespVOS = caxxMapper.selectListForIdentify(pageReqVO.getKqId(), null);
                    return storeRespVOS;
                }else if (YXZT.SELECT.getCode().equals(pageReqVO.getYxcf())){

                }

            }
        }
        return null;
    }

    @Override
    @Transactional
    public void updateSelectedCaxx(CaxxUpdateReqVO updateReqVO) {
        Long loginUserId = SecurityFrameworkUtils.getLoginUser().getId();
        //获取当前用户角色
        List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
        if (ObjectUtils.isEmpty(userRoleList)) {
            throw exception(ERROR, "不存在角色信息");
        }
        String areaLevel = updateReqVO.getAreaLevel();
        // 国家交易中心已选
        if ("0".equals(areaLevel) || ObjectUtil.isEmpty(areaLevel)) {
            createCaAndKuAndDWForSheng(updateReqVO);
        }
        if ("1".equals(areaLevel)) {
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {// 银行已选
                List<BankDO> bankDOS = new ArrayList<>();
                for (Long caId : updateReqVO.getIds()) {
                    BankDO bankDO = new BankDO();
                    bankDO.setCaId(caId);
                    bankDO.setKqId(updateReqVO.getKqId());
                    bankDO.setId(YitIdHelper.nextId());
                    bankDOS.add(bankDO);
                }
                if (!ObjectUtils.isEmpty(bankDOS)) {
                    bankMapper.insertBatch(bankDOS);
                }
            } else {// 省已选
                List<ProvinceDO> provinceDOS = new ArrayList<>();
                for (Long caId : updateReqVO.getIds()) {
                    ProvinceDO province = new ProvinceDO();
                    province.setCaId(caId);
                    province.setKqId(updateReqVO.getKqId());
                    province.setId(YitIdHelper.nextId());
                    province.setDeleted(false);
                    provinceDOS.add(province);
                }
                if (!ObjectUtils.isEmpty(provinceDOS)) {
                    provinceMapper.insertBatch(provinceDOS);
                }
            }
        }
    }

    @Override
    @Transactional
    public void revertCaxx(CaxxUpdateReqVO updateReqVO) {
        Long loginUserId = SecurityFrameworkUtils.getLoginUser().getId();
        //获取当前用户角色
        List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
        if (ObjectUtils.isEmpty(userRoleList)) {
            throw exception(ERROR, "不存在角色信息");
        }
        String areaLevel = updateReqVO.getAreaLevel();
        // 国家交易中心
        if ("0".equals(areaLevel) || ObjectUtil.isEmpty(areaLevel)) {
            //校验是否该仓房是否存在省已经选用或者银行已经选用
            List<ProvinceDO> provinceDOS = provinceMapper.selectOneBycaIds(updateReqVO.getIds());
            if (!ObjectUtils.isEmpty(provinceDOS)) {
                throw exception(ERROR, "存在仓房已经被省选用");
            }
            List<BankDO> bankDOS = bankMapper.selectOneBycaIds(updateReqVO.getIds());
            if (!ObjectUtils.isEmpty(bankDOS)) {
                throw exception(ERROR, "存在仓房已经被银行选用");
            }
            caxxMapper.deleteByIds(updateReqVO.getIds());
            List<CaxxDO> caxxDOS = caxxMapper.selectListByKqId(updateReqVO.getKqId());
            if (ObjectUtils.isEmpty(caxxDOS)) {
                kqxxMapper.deleteByKqId(updateReqVO.getKqId());
                CwxxDO cwxxDO = cwxxMapper.selectByKqId(updateReqVO.getKqId());
                if (!ObjectUtil.isEmpty(cwxxDO)) {
                    Long cwxxDOId = cwxxDO.getId();
                    cwxxMapper.deleteById(cwxxDOId);
                    cwxxYearMapper.deleteListByCwxxId(cwxxDOId);
                }
                //校验是否存在使用该库区单位的其他库区,不存在其他库区则删除该单位信息
                List<KqxxDO> kqxxDOS = kqxxMapper.selectListByDwId(updateReqVO.getDeptId());
                if (ObjectUtils.isEmpty(kqxxDOS)) {
                    dwxxMapper.deleteByDwId(updateReqVO.getDeptId());
                }
            }
        }
        if ("1".equals(areaLevel)) {
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                // 银行已选
                bankMapper.deleteListByKqIdAndCaIds(updateReqVO.getKqId(), updateReqVO.getIds());
            } else {
                // 省已选,先校验是否存在银行已经选的
                List<BankDO> bankDOS = bankMapper.selectOneBycaIds(updateReqVO.getIds());
                if (!ObjectUtils.isEmpty(bankDOS)) {
                    throw exception(ERROR, "存在仓房已经被银行选用");
                }
                provinceMapper.deleteListByKqIdAndCaIds(updateReqVO.getKqId(), updateReqVO.getIds());
                KqxxDO kqxxDO = kqxxMapper.selectById(updateReqVO.getKqId());
                if (ObjectUtils.isEmpty(kqxxDO)) {
                    throw exception(ERROR, "库区信息不存在");
                }
                Integer sjly = kqxxDO.getSjly();
                if (sjly != null && sjly == 0) {
                    //新建的库区，如果省退回全部的仓房则删除库区的全部信息
                    List<ProvinceDO> provinceDOS = provinceMapper.selectListByKqId(updateReqVO.getKqId());
                    if (ObjectUtils.isEmpty(provinceDOS)) {
                        kqxxMapper.deleteByKqId(updateReqVO.getKqId());
                        caxxMapper.deleteListByKqId(updateReqVO.getKqId());
                        CwxxDO cwxxDO = cwxxMapper.selectByKqId(updateReqVO.getKqId());
                        if (!ObjectUtil.isEmpty(cwxxDO)) {
                            Long cwxxDOId = cwxxDO.getId();
                            cwxxMapper.deleteById(cwxxDOId);
                            cwxxYearMapper.deleteListByCwxxId(cwxxDOId);
                        }
                        //校验是否存在使用该库区单位的其他库区,不存在其他库区则删除该单位信息
                        List<KqxxDO> kqxxDOS = kqxxMapper.selectListByDwId(updateReqVO.getDeptId());
                        if (ObjectUtils.isEmpty(kqxxDOS)) {
                            dwxxMapper.deleteByDwId(updateReqVO.getDeptId());
                        }
                    }
                }
            }
        }
    }

    @Override
    @Transactional
    public void revertKqxx(List<Long> kqIds,String areaLevel) {
        Long loginUserId = SecurityFrameworkUtils.getLoginUser().getId();
        //获取当前用户角色
        List<UserRoleDO> userRoleList = userRoleMapper.selectListByUserId(loginUserId);
        if (ObjectUtils.isEmpty(userRoleList)) {
            throw exception(ERROR, "不存在角色信息");
        }
        // 国家交易中心
        if ("0".equals(areaLevel) || ObjectUtil.isEmpty(areaLevel)) {
            if (!ObjectUtil.isEmpty(kqIds)) {
                for (Long kqId : kqIds) {
                    KqxxDO kqxxDO = kqxxMapper.selectById(kqId);
                    if (ObjectUtils.isEmpty(kqxxDO)) {
                        throw exception(ERROR, "库区信息不存在");
                    }
                    //校验是否该库区是否存在省已经选用或者银行已经选用
                    List<ProvinceDO> provinceDOS = provinceMapper.selectListByKqId(kqId);
                    if (!ObjectUtils.isEmpty(provinceDOS)){
                        throw exception(ERROR, "存在库区已经被省选用,不允许删除!");
                    }
                    List<BankDO> bankDOS = bankMapper.selectListByKqId(kqId);
                    if (!ObjectUtils.isEmpty(bankDOS)){
                        throw exception(ERROR, "存在库区已经被银行选用,不允许删除!");
                    }
                    Long dwId = kqxxDO.getDwid();
                    caxxMapper.deleteListByKqId(kqId);
                    kqxxMapper.deleteByKqId(kqId);
                    CwxxDO cwxxDO = cwxxMapper.selectByKqId(kqId);
                    if (!ObjectUtil.isEmpty(cwxxDO)) {
                        Long cwxxDOId = cwxxDO.getId();
                        cwxxMapper.deleteById(cwxxDOId);
                        cwxxYearMapper.deleteListByCwxxId(cwxxDOId);
                    }
                    //校验是否存在使用该库区单位的其他库区,不存在其他库区则删除该单位信息
                    List<KqxxDO> kqxxDOS = kqxxMapper.selectListByDwId(dwId);
                    if (ObjectUtils.isEmpty(kqxxDOS)) {
                        dwxxMapper.deleteByDwId(dwId);
                    }
                }
            }
        }
        if ("1".equals(areaLevel)) {
            List<Long> roleIdList = userRoleList.stream().map(UserRoleDO::getRoleId).distinct().collect(Collectors.toList());
            if (roleIdList.contains(RoleIdEnum.BANK_ADMIN.getRoleId())) {
                // 银行已选
                bankMapper.deleteListByKqIds(kqIds);
            } else {
                // 省已选
                provinceMapper.deleteListByKqIds(kqIds);
                if (!ObjectUtil.isEmpty(kqIds)) {
                    for (Long kqId : kqIds) {
                        KqxxDO kqxxDO = kqxxMapper.selectById(kqId);
                        if (ObjectUtils.isEmpty(kqxxDO)) {
                            throw exception(ERROR, "库区信息不存在");
                        }
                        List<BankDO> bankDOS = bankMapper.selectListByKqId(kqId);
                        if (!ObjectUtils.isEmpty(bankDOS)){
                            throw exception(ERROR, "存在库区已经被银行选用,不允许删除!");
                        }
                        Long dwId = kqxxDO.getDwid();
                        Integer sjly = kqxxDO.getSjly();
                        if (sjly != null && sjly == 0) {
                            //新建的库区，如果省退回全部的仓房则删除库区的全部信息
                            List<ProvinceDO> provinceDOS = provinceMapper.selectListByKqId(kqId);
                            if (ObjectUtils.isEmpty(provinceDOS)) {
                                caxxMapper.deleteListByKqId(kqId);
                                kqxxMapper.deleteByKqId(kqId);
                                CwxxDO cwxxDO = cwxxMapper.selectByKqId(kqId);
                                if (!ObjectUtil.isEmpty(cwxxDO)) {
                                    Long cwxxDOId = cwxxDO.getId();
                                    cwxxMapper.deleteById(cwxxDOId);
                                    cwxxYearMapper.deleteListByCwxxId(cwxxDOId);
                                }
                                //校验是否存在使用该库区单位的其他库区,不存在其他库区则删除该单位信息
                                List<KqxxDO> kqxxDOS = kqxxMapper.selectListByDwId(dwId);
                                if (ObjectUtils.isEmpty(kqxxDOS)) {
                                    dwxxMapper.deleteByDwId(dwId);
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    @Override
    public PageResult<SpareRespVO> getProvinceSelectedPage(SparePageReqVO pageReqVO) {
        if (StringUtils.isNotBlank(pageReqVO.getDwmc())) {
            pageReqVO.setDwmc(String.format("%s%s%s", "%", pageReqVO.getDwmc(), "%"));
        }
        Long loginUserId = SecurityFrameworkUtils.getLoginUserId();
        AdminUserDO adminUserDO = adminUserMapper.selectById(loginUserId);
        if (ObjectUtils.isEmpty(adminUserDO)) {
            throw exception(ERROR, "不存在用户信心信息");
        }
        Integer areaLevel = adminUserDO.getAreaLevel();
        Page<SpareRespVO> page = new Page<SpareRespVO>();
        // 国家交易中心已选
        if (0 == areaLevel || ObjectUtil.isEmpty(areaLevel)) {
            page = caxxMapper.selectWrapperPageForSheng(new Page<>(pageReqVO.getPageNo(), pageReqVO.getPageSize()), pageReqVO);
        }
        return new PageResult<SpareRespVO>(page.getRecords(), page.getTotal());
    }

    @Transactional
    public void createCaAndKuAndDWForSheng(CaxxUpdateReqVO updateReqVO) {
        if (updateReqVO.getKqId() != null) {
            KqxxDO kqxxDOExist = kqxxMapper.selectById(updateReqVO.getKqId());
            if (ObjectUtils.isEmpty(kqxxDOExist)) {
                CodingKqxxDO codingKqxxDO = codingKqxxMapper.selectById(updateReqVO.getKqId());
                if (ObjectUtils.isEmpty(codingKqxxDO)) {
                    throw exception(ERROR, "当前库区信息不存在！");
                }
                KqxxDO kqxxDO = BeanUtils.toBean(codingKqxxDO, KqxxDO.class);
                String shengAll = kqxxDO.getSheng();
                String[] parts = shengAll.split(",");
                for (int i = 0; i < parts.length; i++) {
                    parts[i] = parts[i].trim(); // 去除空格
                }
                String province = null;
                String city = null;
                String county = null;
                if (parts.length != 0) {
                    province = parts[0];
                    if (parts.length == 3) {
                        city = parts[1];
                        county = parts[2];
                    }
                    if (parts.length == 2) {
                        city = parts[1];
                    }
                }
                List<AreaLevelDO> areaLevelDOS = areaLevelMapper.selectListByName(Arrays.asList(province, city, county));
                if (ObjectUtils.isEmpty(areaLevelDOS)) {
                    throw exception(ERROR, "当前库区所在的行政区划不存在！");
                }
                Map<String, String> map = areaLevelDOS.stream().collect(Collectors.toMap(AreaLevelDO::getAreaName, AreaLevelDO::getAreaCode, (x, y) -> x));
                if (province != null) {
                    String shengCode = map.get(province);
                    kqxxDO.setSheng(shengCode);
                }
                if (city != null) {
                    String shiCode = map.get(city);
                    kqxxDO.setShi(shiCode);
                }
                if (county != null) {
                    String xianCode = map.get(county);
                    kqxxDO.setXian(xianCode);
                }
                kqxxDO.setSjly(1);
                kqxxMapper.insert(kqxxDO);
            }
        }
        if (updateReqVO.getDeptId() != null) {
            //一个单位对应多个库区
            DwxxDO dwxxDOExist = dwxxMapper.selectById(updateReqVO.getDeptId());
            if (ObjectUtils.isEmpty(dwxxDOExist)) {
                CodingDwxxDO codingDwxxDO = codingDwxxMapper.selectById(updateReqVO.getDeptId());
                if (ObjectUtils.isEmpty(codingDwxxDO)) {
                    throw exception(ERROR, "当前单位信息不存在！");
                }
                DwxxDO dwxxDO = BeanUtils.toBean(codingDwxxDO, DwxxDO.class);
                dwxxDO.setSjly(1);
                dwxxMapper.insert(dwxxDO);
            }
        }
        if (!ObjectUtils.isEmpty(updateReqVO.getIds())) {
            List<CodingCaxxDO> codingCaxxDOS = codingCaxxMapper.selectList(CodingCaxxDO::getId, updateReqVO.getIds());
            if (ObjectUtils.isEmpty(codingCaxxDOS)) {
                throw exception(ERROR, "所选仓房信息不存在！");
            }
            List<CaxxDO> caxxDOSExist = caxxMapper.selectListByKqId(updateReqVO.getKqId());
            List<CaxxDO> caxxDOS = BeanUtils.toBean(codingCaxxDOS, CaxxDO.class);
            if (!ObjectUtils.isEmpty(caxxDOS)) {
                if (!ObjectUtils.isEmpty(caxxDOSExist)) {
                    List<Long> idsExist = caxxDOSExist.stream().map(CaxxDO::getId).collect(Collectors.toList());
                    caxxDOS.removeIf(caxxDO -> idsExist.contains(caxxDO.getId()));
                }
                if (!ObjectUtils.isEmpty(caxxDOS)) {
                    caxxDOS.stream().forEach(s -> {
                        s.setSjly(1);
                        s.setYxcf(1);
                    });
                    caxxMapper.insertBatch(caxxDOS);
                }
            }
        }
    }



}