package com.unis.module.coding.service.hwk;

import com.github.yitter.idgen.YitIdHelper;
import com.unis.framework.common.pojo.PageResult;
import com.unis.module.coding.controller.admin.hwk.vo.HwkPageReqVO;
import com.unis.module.coding.controller.admin.hwk.vo.HwkSaveReqVO;
import com.unis.module.coding.dal.dataobject.hwk.HwkDO;
import com.unis.module.coding.dal.mysql.hwk.HwkMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import com.unis.framework.common.util.object.BeanUtils;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.HWK_NOT_EXISTS;

/**
 * 货位卡信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class HwkServiceImpl implements HwkService {

    @Resource
    private HwkMapper hwkMapper;

    @Override
    public Long createHwk(HwkSaveReqVO createReqVO) {
        // 插入
        HwkDO hwk = BeanUtils.toBean(createReqVO, HwkDO.class);
        hwk.setId(YitIdHelper.nextId());
        hwkMapper.insert(hwk);
        // 返回
        return hwk.getId();
    }

    @Override
    public void updateHwk(HwkSaveReqVO updateReqVO) {
        // 校验存在
        validateHwkExists(updateReqVO.getId());
        // 更新
        HwkDO updateObj = BeanUtils.toBean(updateReqVO, HwkDO.class);
        hwkMapper.updateById(updateObj);
    }

    @Override
    public void deleteHwk(Long id) {
        // 校验存在
        validateHwkExists(id);
        // 删除
        hwkMapper.deleteById(id);
    }

    private void validateHwkExists(Long id) {
        if (hwkMapper.selectById(id) == null) {
            throw exception(HWK_NOT_EXISTS);
        }
    }

    @Override
    public HwkDO getHwk(Long id) {
        return hwkMapper.selectById(id);
    }

    @Override
    public PageResult<HwkDO> getHwkPage(HwkPageReqVO pageReqVO) {
        return hwkMapper.selectPage(pageReqVO);
    }

}