package com.unis.module.coding.service.lqjcxx;

import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.util.object.BeanUtils;
import com.unis.module.coding.controller.admin.lqjcxx.vo.LqjcxxPageReqVO;
import com.unis.module.coding.controller.admin.lqjcxx.vo.LqjcxxSaveReqVO;
import com.unis.module.coding.dal.dataobject.lqjcxx.LqjcxxDO;
import com.unis.module.coding.dal.mysql.lqjcxx.LqjcxxMapper;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.LQJCXX_NOT_EXISTS;

/**
 * 粮情检测信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class LqjcxxServiceImpl implements LqjcxxService {

    @Resource
    private LqjcxxMapper lqjcxxMapper;

    @Override
    public Long createLqjcxx(LqjcxxSaveReqVO createReqVO) {
        // 插入
        LqjcxxDO lqjcxx = BeanUtils.toBean(createReqVO, LqjcxxDO.class);
        lqjcxxMapper.insert(lqjcxx);
        // 返回
        return lqjcxx.getId();
    }

    @Override
    public void updateLqjcxx(LqjcxxSaveReqVO updateReqVO) {
        // 校验存在
        validateLqjcxxExists(updateReqVO.getId());
        // 更新
        LqjcxxDO updateObj = BeanUtils.toBean(updateReqVO, LqjcxxDO.class);
        lqjcxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteLqjcxx(Long id) {
        // 校验存在
        validateLqjcxxExists(id);
        // 删除
        lqjcxxMapper.deleteById(id);
    }

    private void validateLqjcxxExists(Long id) {
        if (lqjcxxMapper.selectById(id) == null) {
            throw exception(LQJCXX_NOT_EXISTS);
        }
    }

    @Override
    public LqjcxxDO getLqjcxx(Long id) {
        return lqjcxxMapper.selectById(id);
    }

    @Override
    public PageResult<LqjcxxDO> getLqjcxxPage(LqjcxxPageReqVO pageReqVO) {
        return lqjcxxMapper.selectPage(pageReqVO);
    }

}