package com.unis.module.coding.service.province;

import com.unis.module.coding.controller.admin.province.vo.ProvincePageReqVO;
import com.unis.module.coding.controller.admin.province.vo.ProvinceSaveReqVO;
import com.unis.module.coding.dal.dataobject.province.ProvinceDO;
import com.unis.module.coding.dal.mysql.province.ProvinceMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.pojo.PageParam;
import com.unis.framework.common.util.object.BeanUtils;
import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.system.enums.ErrorCodeConstants.PROVINCE_NOT_EXISTS;


/**
 * 省已选 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class ProvinceServiceImpl implements ProvinceService {

    @Resource
    private ProvinceMapper provinceMapper;

    @Override
    public Long createProvince(ProvinceSaveReqVO createReqVO) {
        // 插入
        ProvinceDO province = BeanUtils.toBean(createReqVO, ProvinceDO.class);
        provinceMapper.insert(province);
        // 返回
        return province.getId();
    }

    @Override
    public void updateProvince(ProvinceSaveReqVO updateReqVO) {
        // 校验存在
        validateProvinceExists(updateReqVO.getId());
        // 更新
        ProvinceDO updateObj = BeanUtils.toBean(updateReqVO, ProvinceDO.class);
        provinceMapper.updateById(updateObj);
    }

    @Override
    public void deleteProvince(Long id) {
        // 校验存在
        validateProvinceExists(id);
        // 删除
        provinceMapper.deleteById(id);
    }

    private void validateProvinceExists(Long id) {
        if (provinceMapper.selectById(id) == null) {
            throw exception(PROVINCE_NOT_EXISTS);
        }
    }

    @Override
    public ProvinceDO getProvince(Long id) {
        return provinceMapper.selectById(id);
    }

    @Override
    public PageResult<ProvinceDO> getProvincePage(ProvincePageReqVO pageReqVO) {
        return provinceMapper.selectPage(pageReqVO);
    }

}