package com.unis.module.coding.service.spxx;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import com.unis.module.coding.controller.admin.spxx.vo.*;
import com.unis.module.coding.dal.dataobject.spxx.SpxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.pojo.PageParam;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.spxx.SpxxMapper;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.SPXX_NOT_EXISTS;

/**
 * 视频信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class SpxxServiceImpl implements SpxxService {

    @Resource
    private SpxxMapper spxxMapper;

    @Override
    public Long createSpxx(SpxxSaveReqVO createReqVO) {
        // 插入
        SpxxDO spxx = BeanUtils.toBean(createReqVO, SpxxDO.class);
        spxxMapper.insert(spxx);
        // 返回
        return spxx.getId();
    }

    @Override
    public void updateSpxx(SpxxSaveReqVO updateReqVO) {
        // 校验存在
        validateSpxxExists(updateReqVO.getId());
        // 更新
        SpxxDO updateObj = BeanUtils.toBean(updateReqVO, SpxxDO.class);
        spxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteSpxx(Long id) {
        // 校验存在
        validateSpxxExists(id);
        // 删除
        spxxMapper.deleteById(id);
    }

    private void validateSpxxExists(Long id) {
        if (spxxMapper.selectById(id) == null) {
            throw exception(SPXX_NOT_EXISTS);
        }
    }

    @Override
    public SpxxDO getSpxx(Long id) {
        return spxxMapper.selectById(id);
    }

    @Override
    public PageResult<SpxxDO> getSpxxPage(SpxxPageReqVO pageReqVO) {
        return spxxMapper.selectPage(pageReqVO);
    }

}