package com.unis.module.coding.service.zjxx;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import com.unis.module.coding.controller.admin.zjxx.vo.*;
import com.unis.module.coding.dal.dataobject.zjxx.ZjxxDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.pojo.PageParam;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.coding.dal.mysql.zjxx.ZjxxMapper;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.core.enums.ErrorCodeConstants.ZJXX_NOT_EXISTS;

/**
 * 质检信息 Service 实现类
 *
 * @author 超级管理员
 */
@Service
@Validated
public class ZjxxServiceImpl implements ZjxxService {

    @Resource
    private ZjxxMapper zjxxMapper;

    @Override
    public Long createZjxx(ZjxxSaveReqVO createReqVO) {
        // 插入
        ZjxxDO zjxx = BeanUtils.toBean(createReqVO, ZjxxDO.class);
        zjxxMapper.insert(zjxx);
        // 返回
        return zjxx.getId();
    }

    @Override
    public void updateZjxx(ZjxxSaveReqVO updateReqVO) {
        // 校验存在
        validateZjxxExists(updateReqVO.getId());
        // 更新
        ZjxxDO updateObj = BeanUtils.toBean(updateReqVO, ZjxxDO.class);
        zjxxMapper.updateById(updateObj);
    }

    @Override
    public void deleteZjxx(Long id) {
        // 校验存在
        validateZjxxExists(id);
        // 删除
        zjxxMapper.deleteById(id);
    }

    private void validateZjxxExists(Long id) {
        if (zjxxMapper.selectById(id) == null) {
            throw exception(ZJXX_NOT_EXISTS);
        }
    }

    @Override
    public ZjxxDO getZjxx(Long id) {
        return zjxxMapper.selectById(id);
    }

    @Override
    public PageResult<ZjxxDO> getZjxxPage(ZjxxPageReqVO pageReqVO) {
        return zjxxMapper.selectPage(pageReqVO);
    }

}