package com.unis.module.system.service.arealevel;

import cn.hutool.core.util.ObjectUtil;
import com.unis.framework.security.core.LoginUser;
import com.unis.framework.security.core.util.SecurityFrameworkUtils;
import com.unis.module.system.dal.dataobject.user.AdminUserDO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

import com.unis.module.system.controller.admin.arealevel.vo.*;
import com.unis.module.system.dal.dataobject.arealevel.AreaLevelDO;
import com.unis.framework.common.pojo.PageResult;
import com.unis.framework.common.pojo.PageParam;
import com.unis.framework.common.util.object.BeanUtils;

import com.unis.module.system.dal.mysql.arealevel.AreaLevelMapper;

import static com.unis.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.unis.module.system.enums.ErrorCodeConstants.*;

/**
 * 行政区划 Service 实现类
 *
 * @author 超级管理员
 */
@Slf4j
@Service
@Validated
public class AreaLevelServiceImpl implements AreaLevelService {

    @Resource
    private AreaLevelMapper areaLevelMapper;

    @Override
    public Integer createAreaLevel(AreaLevelSaveReqVO createReqVO) {
        // 插入
        AreaLevelDO areaLevel = BeanUtils.toBean(createReqVO, AreaLevelDO.class);
        areaLevelMapper.insert(areaLevel);
        // 返回
        return areaLevel.getId();
    }

    @Override
    public void updateAreaLevel(AreaLevelSaveReqVO updateReqVO) {
        // 校验存在
        validateAreaLevelExists(updateReqVO.getId());
        // 更新
        AreaLevelDO updateObj = BeanUtils.toBean(updateReqVO, AreaLevelDO.class);
        areaLevelMapper.updateById(updateObj);
    }

    @Override
    public void deleteAreaLevel(Integer id) {
        // 校验存在
        validateAreaLevelExists(id);
        // 删除
        areaLevelMapper.deleteById(id);
    }

    private void validateAreaLevelExists(Integer id) {
        if (areaLevelMapper.selectById(id) == null) {
            throw exception(AREA_LEVEL_NOT_EXISTS);
        }
    }

    @Override
    public AreaLevelDO getAreaLevel(Integer id) {
        return areaLevelMapper.selectById(id);
    }

    @Override
    public List<AreaLevelDO> getAreaShengLevel() {
        return areaLevelMapper.selectShengLevel();

    }

    @Override
    public List<AreaLevelDO> getAreaListByParentCode(String parentCode) {
        return areaLevelMapper.selectListByParentCode(parentCode);
    }

    @Override
    public List<AreaLevelDO> getAreaLevelListAll(AdminUserDO user) {
        log.info("user: {}", user);
        //国家局或者管理员
        if (ObjectUtil.isEmpty(user.getAreaLevel()) || user.getAreaLevel() == 0) {
            AreaLevelDO areaLevelDO = new AreaLevelDO();
            areaLevelDO.setAreaLevel(0);
            areaLevelDO.setAreaCode("0");
            areaLevelDO.setAreaName("国家粮食交易中心");
            areaLevelDO.setId(0);
            List<AreaLevelDO> temp = areaLevelMapper.selectList();
            temp.add(areaLevelDO);
            return  temp;

        }
        // 省一级用户
        else if (user.getAreaLevel() == 1) {
            AreaLevelDO areaLevelDO = areaLevelMapper.selectListByAreaCode(user.getAreaCode());
            List<AreaLevelDO> temp = getSubAreasRecursively(user.getAreaCode());
            temp.add(areaLevelDO);
            return temp;
        }
        // 市一级用户
        else if (user.getAreaLevel() == 2) {
            AreaLevelDO areaLevelDO = areaLevelMapper.selectListByAreaCode(user.getAreaCode());
            List<AreaLevelDO> temp = getSubAreasRecursively(user.getAreaCode());
            temp.add(areaLevelDO);
            return temp;
        }
        // 县一级用户
        else if (user.getAreaLevel() == 3) {
            // 县级是最低级别，只返回自身
            AreaLevelDO areaLevelDO = areaLevelMapper.selectListByAreaCode(user.getAreaCode());
            return Collections.singletonList(areaLevelDO);
        }
        // 返回空列表或其他默认行为
        return Collections.emptyList();
    }

    private List<AreaLevelDO> getSubAreasRecursively(String parentCode) {
        List<AreaLevelDO> subAreas = areaLevelMapper.selectListByParentCode(parentCode);
        if (ObjectUtil.isEmpty(subAreas) || subAreas.isEmpty()) {
            return subAreas;
        }
        List<AreaLevelDO> allSubAreas = new ArrayList<>(subAreas);
        for (AreaLevelDO area : subAreas) {
            allSubAreas.addAll(getSubAreasRecursively(area.getAreaCode()));
        }
        return allSubAreas;
    }

    @Override
    public PageResult<AreaLevelDO> getAreaLevelPage(AreaLevelPageReqVO pageReqVO) {
        return areaLevelMapper.selectPage(pageReqVO);
    }

}